@@ -1,5 +1,6 @@
 from datetime import datetime
-
+from django import forms
+from django.db import models
 from django.contrib import admin
 from django.contrib.admin import ModelAdmin 
 
@@ -12,6 +13,10 @@ class CSVImportAdmin(ModelAdmin):
                        'upload_method',
                        'error_log',
                        'import_user']
+    formfield_overrides = {
+        models.CharField: {'widget': forms.Textarea(attrs={'rows':'4', 
+                                                           'cols':'60'})},
+        }
 
     def save_model(self, request, obj, form, change):
         """ Do save and process command - cant commit False
@@ -37,22 +42,11 @@ class CSVImportAdmin(ModelAdmin):
 
     def filename_defaults(self, filename):
         """ Override this method to supply filename based data """
-        # example ORG-COUNTRY.csv
         defaults = []
-        splitters = {'/':-1,'.':0,'_':0}
+        splitters = {'/':-1, '.':0, '_':0}
         for splitter, index in splitters.items():
             if filename.find(splitter)>-1:
                 filename = filename.split(splitter)[index]
-        try:
-            org, country = filename.split('-')
-            country = country[0:2].upper()
-            org = org.upper()
-        except:
-            return defaults
-        if org:
-            defaults.append(('organisation', org, ('Organisation', 'name')))
-        if country:
-            defaults.append(('country', country, ('Country', 'code')))
         return defaults
 
 admin.site.register(CSVImport, CSVImportAdmin)
